@@ -1,4 +1,5 @@
-from handler import *
+from deskbar.Handler import *
+from deskbar.Match import *
 from time import sleep
 import gobject
 
@@ -11,14 +12,17 @@ HANDLERS = {
 SIGNAL_DELAY = 1000 # 1 sec.
 
 class SignallingDebugMatch (Match):
-	def __init__(self, handler, name, icon=None):
-		Match.__init__ (self, handler, name)
+	def __init__(self, handler, **args):
+		Match.__init__ (self, handler, **args)
 		
 	def get_verb(self):
 		return "%(name)s - %(text)s"
 		
 	def action(self, text=None):
 		print str(self.__class__) + " : action triggered"
+		
+	def get_category (self):
+		return "debug"
 
 
 class SignallingDebugHandler(SignallingHandler):
@@ -30,8 +34,8 @@ class SignallingDebugHandler(SignallingHandler):
 		self.sig = gobject.timeout_add(SIGNAL_DELAY, lambda : self.__callback(qstring))
 
 	def __callback(self, qstring):
-		match = SignallingDebugMatch(self, "SignallingDebug:"+qstring)
-		self.emit_query_ready([match], qstring)
+		match = SignallingDebugMatch(self, name="Signalling :"+qstring)
+		self.emit_query_ready(qstring, [match])
 		
 		# Keep sending the results, see if filter works ok
 		return True
