@@ -25,73 +25,86 @@ class CuemiacAlignedWindow (gtk.Window):
 		self.applet = applet
 		self.alignment = applet.get_orient ()
 
-		self.is_realized = False
+		self.realize_status = None
 		self.connect ("realize", lambda win : self.__register_realize ())
+		self.connect ("size-allocate", self.__resize_event)
 		
+	def __resize_event (self, event, data):
+		self.update_position ()
+	
 	def update_position (self):
 		"""
 		Calculates the position and moves the window to it.
 		IMPORATNT: widgetToAlignWith should be realized!
 		"""
-		if not self.is_realized:
+		if self.realize_status == None:
+			self.realize_status = False
 			self.realize ()
+			return
+		
+		if self.realize_status == False:
+			return
 			
 		# Get our own dimensions & position
-		window_width  = (self.window.get_geometry())[2]
-	   	window_height = (self.window.get_geometry())[3]
+		(wx, wy) = self.window.get_origin ()
+		(ax, ay) = self.widgetToAlignWith.window.get_origin ()
 
-		# Get the dimensions/position of the widgetToAlignWith
-		(x, y) = self.widgetToAlignWith.window.get_origin()
-
-		(w, h) = self.size_request()
-
-		target_w = self.widgetToAlignWith.allocation.width
-		target_h = self.widgetToAlignWith.allocation.height
+		(ww, wh) = self.window.get_size ()
+		(aw, ah) = self.widgetToAlignWith.window.get_size ()
 
 		screen = self.get_screen()
-		# XXX: FIXME: we should get the monitor that the applet is on,
-		# not the realised window
 		monitor = screen.get_monitor_geometry (screen.get_monitor_at_window (self.applet.window))
 		
-		#print "monitor %i" % screen.get_monitor_at_window (self.applet.window)
-		#print "x = %i, y = %i, w = %i, h = %i" % (x, y, target_w, target_h)
-		#print "monitor: x = %i, y = %i, w = %i, h = %i" % (monitor.x, monitor.y, monitor.width, monitor.height)
-		
 		if self.alignment == gnomeapplet.ORIENT_RIGHT:
-				x += target_w
+				x = ax - ww
+				y = ay
 
-				if ((y + h) > monitor.y + monitor.height):
-						y -= (y + h) - (monitor.y + monitor.height)
+				if (y + wh > monitor.y + monitor.height):
+					y = monitor.y + monitor.height - wh
+
+				if (y < 0):
+					y = 0
 				
-				if ((y + h) > (monitor.height / 2)):
-						gravity = gtk.gdk.GRAVITY_SOUTH_WEST	
+				if (y + wh > monitor.height / 2):
+					gravity = gtk.gdk.GRAVITY_SOUTH_WEST	
 				else:
-						gravity = gtk.gdk.GRAVITY_NORTH_WEST
+					gravity = gtk.gdk.GRAVITY_NORTH_WEST
+					
 		elif self.alignment == gnomeapplet.ORIENT_LEFT:
-				x -= w
+				x = ax + aw
+				y = ay
 
-				if ((y + h) > monitor.y + monitor.height):
-						y -= (y + h) - (monitor.y + monitor.height)
+				if (y + wh > monitor.y + monitor.height):
+					y = monitor.y + monitor.height - wh
 				
-				if ((y + h) > (monitor.height / 2)):
-						gravity = gtk.gdk.GRAVITY_SOUTH_EAST
+				if (y < 0):
+					y = 0
+				
+				if (y + wh > monitor.height / 2):
+					gravity = gtk.gdk.GRAVITY_SOUTH_EAST
 				else:
-						gravity = gtk.gdk.GRAVITY_NORTH_EAST
-		elif self.alignment == gnomeapplet.ORIENT_DOWN:
-				print "got alignment:DOWN"
-				y += target_h
+					gravity = gtk.gdk.GRAVITY_NORTH_EAST
 
-				if ((x + target_w) > (monitor.x + monitor.width)):
-					print "will exceed monitor"
-					x -= (x + w) - (monitor.x + monitor.width)
+		elif self.alignment == gnomeapplet.ORIENT_DOWN:
+				x = ax
+				y = ay + ah
+
+				if (x + ww > monitor.x + monitor.width):
+					x = monitor.x + monitor.width - ww
+
+				if (x < 0):
+					x = 0
 
 				gravity = gtk.gdk.GRAVITY_NORTH_WEST
 		elif self.alignment == gnomeapplet.ORIENT_UP:
-				y -= h
-				print h
+				x = ax
+				y = ay - wh
 
-				if ((x + w) > monitor.x + monitor.width):
-						x -= (x + w) - (monitor.x + monitor.width)
+				if (x + ww > monitor.x + monitor.width):
+					x = monitor.x + monitor.width - ww
+
+				if (x < 0):
+					x = 0
 
 				gravity = gtk.gdk.GRAVITY_SOUTH_WEST
 		
@@ -99,6 +112,7 @@ class CuemiacAlignedWindow (gtk.Window):
 		self.set_gravity(gravity)
 	
 	def __register_realize (self):
-		self.is_realized = True
+		self.realize_status = True
+		self.update_position()
 		
 gobject.type_register (CuemiacAlignedWindow)
